/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is hultmann localization tools.
 *
 * The Initial Developer of the Original Code is
 * Jeferson Hultmann <hultmann@gmail.com>
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

namespace LocaleInpector
{

internal sealed class POLocale
{

public static int Main()
{
    int ret = MainCore();
    return ret;
}

private static int MainCore()
{
    string title = "PO Locale " + Config.GetVersion();
    //System.Console.OutputEncoding = BPIO.UTF8;
    System.Console.Title = title;
    System.Console.BackgroundColor = System.ConsoleColor.Blue;
    System.Console.ForegroundColor = System.ConsoleColor.Gray;
    System.Console.Write(title);
    System.Console.Write(" - a converter tool for mozilla extensions localizers.");
    System.Console.ResetColor();

    System.Console.WriteLine();
    System.Console.Write("Latest version: http://downloads.mozdev.org/br/po-locale.zip");
    System.Console.WriteLine();
    System.Console.Write("Jeferson Hultmann, pt-BR localization <hultmann@gmail.com>");
    System.Console.WriteLine();

    // pot
    // [2] original (dir, xpi, jar)
    // [3] output.pot

    // po
    // [2] original (dir, xpi, jar)
    // [3] translated
    // [4] output.po

    // locale
    // [2] input.po
    // [3] original chrome (dir, xpi, jar)
    // [4] output.zip


    string input;
    string auxInput = null;
    string output;
    string[] arguments = System.Environment.GetCommandLineArgs();

    if (arguments.Length < 2) {
        return WriteHeader();
    }

    switch (arguments[1]) {
        case "pot":
            if (arguments.Length < 4) {
                return WriteHeader();
            }
            input  = arguments[2];
            output = arguments[3];
            break;
        case "po":
            if (arguments.Length < 5) {
                return WriteHeader();
            }
            input  = arguments[2];
            auxInput = arguments[3];
            output = arguments[4];
            break;
        case "locale":
            if (arguments.Length < 5) {
                return WriteHeader();
            }
            input = arguments[2];
            auxInput = arguments[3];
            output = arguments[4];
            break;
        default:
            return WriteHeader();
    }

    if (BPIO.Exists(output)) {
        System.Console.ForegroundColor = System.ConsoleColor.Red;
        System.Console.WriteLine("Cannot save {0}. A file with the name you specified already exists.", output);
        System.Console.ResetColor();
        return 1;
    }

    // expired beta version
    /*
    if (System.DateTime.Today > new System.DateTime(2005, 08, 20)) {
        System.Threading.Thread.Sleep(100000);
        return 1;
    }
    */

    switch (arguments[1]) {
        case "locale":
            PoToLocale.Save(input, output, auxInput);
            break;
        case "pot":
            LocaleToPo.Create(input, null, output);
            break;
        case "po":
            LocaleToPo.Create(input, auxInput, output);
            break;
        default:
            throw(new System.InvalidOperationException());
    }

    return 0;
}

private static int WriteHeader()
{
System.Console.Write(
@"
Usage:     po-locale.exe <command> <input1> [input2] <output>

<command>
  pot      Create a pot file searching a jar/xpi for a locale.
           po-locale.exe  pot  original.xpi  output.pot

  po       Create a po file combining two locales from two jar/xpi.
           Use to migrate your current translation.
           po-locale.exe  po  original.xpi  original.xpi?ab-CD  output.po
                                     translated locale---^^^^^

  locale   Convert a po file to a zip containing a translated mozilla locale.
           po-locale.exe  locale  translation.po  original.xpi  output.zip

");

    return 1;
}

}//class
}//ns